@@ -93,6 +93,8 @@ class OpusRead:
         self.tgt_range = tgt_range
 
         self.verbose = verbose
+        if write:
+            self.verbose = True
 
         if self.switch_langs:
             temp = src_range
@@ -190,7 +192,7 @@ class OpusRead:
 
         self.of_handler = OpusFileHandler(
                 download_dir, source_zip, target_zip, directory, release,
-                preprocess, self.fromto, self.verbose, suppress_prompts)
+                preprocess, self.fromto, suppress_prompts)
 
         self.alignment = self.of_handler.open_alignment_file(self.alignment)
         self.alignmentParser = AlignmentParser(self.alignment,
@@ -209,13 +211,32 @@ class OpusRead:
 
         total = 0
         stop = False
+        cur_pos = 0
+
+        if self.verbose:
+            print("\n\n")
+
         while True:
-            link_attrs, src_set, trg_set, src_doc_name, trg_doc_name = \
-                self.alignmentParser.collect_links()
+            link_attrs, src_set, trg_set, src_doc_name, trg_doc_name, progress, cur_pos = \
+                self.alignmentParser.collect_links(cur_pos)
 
             if not src_doc_name:
+                if self.verbose:
+                    message = "Reading alignment file \"{}\" ... 100.0%".format(self.alignment.name)
+                    if self.write:
+                        # \033[F = go to previous line
+                        print("\033[F\033[F\033[F{}\n\n".format(message))
+                    else:
+                        print(message)
                 break
 
+            if self.verbose:
+                message = "Reading alignment file \"{}\" ... {}%".format(self.alignment.name, progress)
+                if self.write:
+                    print("\033[F\033[F\033[F{}".format(message))
+                else:
+                    print(message)
+
             if self.skip_doc(src_doc_name):
                 continue
 
@@ -231,11 +252,13 @@ class OpusRead:
                 try:
                     src_parser = SentenceParser(src_doc,
                             preprocessing=self.preprocess, anno_attrs=self.src_annot,
-                            preserve=self.preserve, delimiter=self.annot_delimiter)
+                            preserve=self.preserve, delimiter=self.annot_delimiter,
+                            verbose=self.verbose)
                     src_parser.store_sentences(src_set)
                     trg_parser = SentenceParser(trg_doc,
                             preprocessing=self.preprocess, anno_attrs=self.trg_annot,
-                            preserve=self.preserve, delimiter=self.annot_delimiter)
+                            preserve=self.preserve, delimiter=self.annot_delimiter,
+                            verbose=self.verbose)
                     trg_parser.store_sentences(trg_set)
                 except SentenceParserError as e:
                     print('\n'+e.message+'\nContinuing from next sentence file pair.')
@@ -281,8 +304,3 @@ class OpusRead:
 
         self.of_handler.close_zipfiles()
 
-        if self.verbose:
-            print('Done')
-
-
-
